@@ -14,6 +14,7 @@ function)
 Requests are handled by class RequestHandler (one instance per request)
 """
 
+import os
 import traceback
 import sys
 
@@ -38,7 +39,6 @@ if k_config.silent:
     sys.stderr = k_utils.silent()
     
 # Launch the server
-import asyncore
 s = Server.Server(('',k_config.port),asyncRequestHandler)
 print "Karrigell %s running on port %s" %(KarrigellRequestHandler.__version__,k_config.port)
 if k_config.debug:
