@@ -17,7 +17,7 @@ from k_encodings import k_encoding_charsets, k_encoding
 from k_stringio import KStringIO as StringIO
 from LocalizedRequestHandler import LocalizedRequestHandler
 
-__version__ = "2.3.2"
+__version__ = "2.3.3"
 
 os.chdir(k_config.serverDir)
 
@@ -37,7 +37,7 @@ mimetypes.types_map.update({
 mimetypes.types_map.update(k_config.extensions_map)
 
 # for imports
-dirs = [ os.getcwd(),os.path.join(os.getcwd(),'buzhug') ]
+dirs = [ os.getcwd() ]
 for dir_ in dirs:
     if not dir_ in sys.path:
         sys.path.append(dir_)
@@ -90,6 +90,10 @@ class KarrigellRequestHandler(LocalizedRequestHandler):
             self.COOKIE=Cookie.SimpleCookie(self.HEADERS["cookie"])
         else:
             self.COOKIE=Cookie.SimpleCookie()
+        # check if cookie logged_user is set
+        self.LOGGED_USER = None
+        if self.COOKIE.has_key('logged_user'):
+            self.LOGGED_USER = self.COOKIE['logged_user'].value
         # SET_COOKIE = cookies sent back to the browser            
         self.SET_COOKIE=Cookie.SimpleCookie()
 
@@ -182,10 +186,13 @@ class KarrigellRequestHandler(LocalizedRequestHandler):
             "RESPONSE":self.RESPONSE,"HEADERS":self.HEADERS,
             "AUTH_USER":self.AUTH_USER,"AUTH_PASSWORD":self.AUTH_PASSWORD,
             "QUERY":self.QUERY,"COOKIE":self.COOKIE,
+            "PATH":self.path,
             "SET_COOKIE":self.SET_COOKIE,
             "ACCEPTED_LANGUAGES":self.accepted_languages,
             "SERVER_DIR":k_config.serverDir,
             "Session":self.Session,"Authentication":self.Authentication,
+            "RestrictToAdmin":self.RestrictToAdmin,
+            "Login":self.Login,"LOGGED_USER":self.LOGGED_USER,
             "os":os,"Cookie":Cookie,"string":string})
             # frequently used modules needn't be imported in scripts
 
@@ -404,7 +411,8 @@ class KarrigellRequestHandler(LocalizedRequestHandler):
         # if fileName is a directory, search an index file and redirect
         elif os.path.isdir(fileName):
             try:
-                indexFile=URLResolution.indexFile(fileName)
+                indexFile = URLResolution.indexFile(fileName)
+                fileName=os.path.join(fileName,indexFile)
             except URLResolution.DuplicateIndexError,msg:
                 self.send_error(300, "More than one index file : %s" %msg)
                 return
@@ -427,13 +435,13 @@ class KarrigellRequestHandler(LocalizedRequestHandler):
                 self.karrigellSendResponse(200,"Ok")
                 return
             if not self.path_without_qs.endswith('/'):
-                self.path=urlparse.urljoin(self.path_without_qs+'/',indexFile)
+                self.path=self.path_without_qs+'/'
+                # make http redirection to destination file
+                self.redirect(self.path)
+                return
             else:
                 self.path=urlparse.urljoin(self.path_without_qs,indexFile)
 
-            # make http redirection to destination file
-            self.redirect(self.path)
-            return
 
         # if file is a ks script with no method, redirect to method 'index'
         if os.path.isfile(fileName) and fileName.lower().endswith('.ks'):
@@ -757,6 +765,29 @@ class KarrigellRequestHandler(LocalizedRequestHandler):
         # message if user cancels authentication request
         raise k_script.AUTH_ABORT
 
+    def RestrictToAdmin(self,admin_file=None):
+        """Used to restrict access to the administrator
+        Uses a file with the admin's login and password md5 hashes"""
+        if admin_file is None:
+            admin_file = os.path.join(k_config.serverDir,'admin','admin.ini')
+        import md5
+        digest=open(admin_file,"rb").read()
+        userDigest=digest[:16]
+        passwordDigest=digest[16:]
+
+        def authTest():
+            return (md5.new(self.AUTH_USER).digest()==userDigest \
+                and md5.new(self.AUTH_PASSWORD).digest()==passwordDigest)
+
+        self.Authentication(authTest,
+            realm=_("Administration"),
+            errorMessage=_("Authentication error"))
+
+    def Login(self,script=None):
+        if script is None:
+            script = os.path.join(k_config.serverDir,'core','login.py')
+        print Template.getScript(script).render(self.nameSpace).value
+        
     def setSessionObject(self):
         """Internal method, initializes the session object
         If the client has sent a cookie named sessionId, takes its value and
