@@ -140,6 +140,7 @@ try:
     _globalScriptsList=conf.get("Server","global").split(";")
     for _globalScript in _globalScriptsList:
         _gPath,_gName=os.path.dirname(_globalScript),os.path.basename(_globalScript)
+        _gPath = os.path.normpath(_gPath)
         if not _gPath in sys.path:
             sys.path.append(_gPath)
         _gName=os.path.splitext(_gName)[0]
@@ -186,10 +187,6 @@ except (ConfigParser.NoOptionError,ConfigParser.NoSectionError):
     pass
 except:
     traceback.print_exc(sys.stderr)
-
-for cgi_dir in cgi_directories:
-    if not os.path.isdir(cgi_dir):
-        raise ConfigError, "cgi directory not found : %s" %cgi_dir
     
 # protected zones : for all scripts, include AuthentScript.py
 protectedDirs=[]
