@@ -132,10 +132,7 @@ class BaseScript:
         pythonCode=self.pythonCode()
         (protectedDir,depth) = k_utils.pathInDirs(self.name,k_config.protectedDirs)
         if protectedDir is not None:
-            authentScriptUrl="../"*depth+"AuthentScript.py"
-            if self.name.lower() != \
-                os.path.join(protectedDir,'AuthentScript.py').lower():
-                self.code='Include("%s");'%authentScriptUrl + self.pythonCode()
+            self.code='RestrictToAdmin();' + self.pythonCode()
 
         saveStdout=sys.stdout
         sys.stdout=StringIO()
