@@ -21,3 +21,6 @@ class KStringIO:
     def write(self, s):
         self.stringio.write(self._enc(s))
 
+    def flush(self):
+        """Added by Henk Jansen for compatibility"""
+        self.kstringio.flush()
\ No newline at end of file
