@@ -37,10 +37,10 @@ class Error:
             if filename=="<string>":
                 break
         [exc_type,exc_value]=exc_info[:2]
-        if type(exc_type) == types.ClassType:
+        try:
             stype = exc_type.__name__
-        else:
-            stype = exc_type
+        except AttributeError:
+            stype = str(exc_type)
         if exc_type in [SyntaxError,IndentationError]:
             exc_type_value=stype
             try:
