@@ -12,6 +12,8 @@ Sun
 
 Fri
 
+Administration
+
 Jan
 
 Server does not support this operation
@@ -40,6 +42,8 @@ May
 
 Error response
 Réponse d'erreur
+Authentication error
+Erreur d'authentification
 Jun
 
 Jul
