@@ -1,4 +1,7 @@
 import cgi
-print cgi.FieldStorage()
 import os
+
+print "Content-type: text/html"
+print
+print cgi.FieldStorage()
 print '<p>query string ',os.environ['QUERY_STRING']
\ No newline at end of file
