@@ -3,7 +3,7 @@ import random
 import datetime
 import string
 
-from buzhug import Base
+from PyDbLite import Base
 
 def word(m):
     res = ''
@@ -20,8 +20,9 @@ def sentence(n,m):
     return ' '.join(res)
     
 os.remove('blog')
-db = Base('blog').create(('parent',int),('title',str),
-    ('author',str),('text',str),('date',datetime.date))
+db = Base('blog').create('parent','title','author','text','date')
+db.create_index('parent')
+
 nbthreads = 200
 for i in range(nbthreads):
     # generate thread
