@@ -1,24 +1,24 @@
 import sys,os, random
-from buzhug import Base
+from PyDbLite import Base
 
 def createBase():
     for path in ('chansons','recueils','dialectes',
-        'genres','chansons_par_dialectes',
-        'chansons_par_recueils'):
+        'genres','chansons_par_dialecte',
+        'chansons_par_recueil'):
         try:
-            Base(path).destroy()
+            os.remove(path+'.skl')
         except OSError:
             pass
 
-    db_genres = Base('genres').create(('nom',str))
-    db_chansons = Base('chansons').create(('url',str),('breton',str),
-        ('francais',str),('prix',int),('genre',db_genres))
-    db_recueils = Base('recueils').create(('nom',str))
-    db_dialectes = Base('dialectes').create(('nom',str))
-    db_ch_par_dial = Base('chansons_par_dialecte').create(
-        ('chanson',db_chansons),('dialecte',db_dialectes))
-    db_ch_par_rec = Base('chansons_par_recueil').create(
-        ('chanson',db_chansons),('recueil',db_recueils))
+    db_genres = Base('genres.skl').create('nom')
+    db_chansons = Base('chansons.skl').create('url','breton',
+        'francais','prix','genre')
+    db_recueils = Base('recueils.skl').create('nom')
+    db_dialectes = Base('dialectes.skl').create('nom')
+    db_ch_par_dial = Base('chansons_par_dialecte.skl').create(
+        'chanson','dialecte')
+    db_ch_par_rec = Base('chansons_par_recueil.skl').create(
+        'chanson','recueil')
 
     chansons=open("base.txt").readlines()
 
@@ -62,16 +62,17 @@ def createBase():
         db_recueils.insert(nom=r)
 
     for ch in l_chansons:
-        ch[-1] = db_genres[ch[-1]]
-        db_chansons.insert(*ch)
+        print ch
+        db_chansons.insert(**dict(zip(db_chansons.fields,ch)))
     for ch_d in chansonsParDialecte:
-        db_ch_par_dial.insert(chanson = db_chansons[ch_d[0]],
-            dialecte = db_dialectes[ch_d[1]])
+        db_ch_par_dial.insert(chanson = ch_d[0],
+            dialecte = ch_d[1])
     for ch_r in chansonsParRecueil:
-        db_ch_par_rec.insert(chanson = db_chansons[ch_r[0]],
-            recueil = db_recueils[ch_r[1]])
-
-if __name__ == '__main__':
-    if not os.path.exists('chansons'):
-        createBase()
+        db_ch_par_rec.insert(chanson = ch_r[0],
+            recueil = ch_r[1])
+    for db in (db_genres,db_dialectes,db_recueils,db_chansons,
+        db_ch_par_dial,db_ch_par_rec):
+            db.commit()
 
+if not os.path.exists('chansons.skl'):
+    createBase()
