@@ -14,6 +14,8 @@ Search
 Rechercher
 Remove
 Enlever
+by dialect
+par dialecte
 removed from your cart
 enlevé de votre panier
 whole list
@@ -28,9 +30,11 @@ was already in your cart
 était déjà dans votre panier
 Your cart is empty
 Votre panier est vide
+songs
+chansons
 Situation of your cart
 Votre panier
 Price
 Prix
-by dialect
-par dialecte
+All the songs
+Toutes les chansons
