@@ -1,6 +1,6 @@
 from agendaDb import db
 
 del db[int(_entryId)]
-db.cleanup()
+db.commit()
 
 raise HTTP_REDIRECTION,"index.pih"
