@@ -7,6 +7,6 @@ passwordDigest=digest[16:]
 if (md5.new(_login).digest()==userDigest \
         and md5.new(_password).digest()==passwordDigest):
     Session().forum_admin = True
-    raise HTTP_REDIRECTION,'index.pih'
+    raise HTTP_REDIRECTION,'index.ks'
 else:
     print 'Administrator login failed'
\ No newline at end of file
