@@ -10,6 +10,8 @@ Answer
 Répondre
 Your message
 Votre message
+answers
+réponses
 Start new thread
 Nouveau sujet
 Your name
