@@ -1,8 +1,4 @@
-print "<html>\n<body>\n"
 print "<p>QUERY %s" %QUERY
-print "<br>Spam is",_spam
+print "<br>Spam is",_spam,"unicode",isinstance(_spam,unicode)
 if QUERY.has_key("animal"):
     print "<br>Animal is",str(QUERY["animal"])
-
-print "</body>\n</html>"
-
